@@ -89,9 +89,9 @@ class Environment(object):
         dummy_parser = self._build_default_parser(doc=doc, version=version,
                                              add_help=False)
         if handle_files:
-            real_parser.add_argument('files', nargs='+',
+            real_parser.add_argument('files', nargs='*',
                                 help='A list of files to act upon (wildcards ok)')
-            dummy_parser.add_argument('files', nargs='+',
+            dummy_parser.add_argument('files', nargs='*',
                                 help='A list of files to act upon (wildcards ok)')
         try:
             context = vars(dummy_parser.parse_known_args()[0])
